import React, { useMemo } from 'react';
import { Modal } from './Modal';
import { Product } from '../types';
import { products } from '../data/products';
import { categories } from '../data/categories';

interface ProductModalProps {
  isOpen: boolean;
  onClose: () => void;
  category: string | null;
  onSelect: (product: Product) => void;
}

export function ProductModal({ isOpen, onClose, category, onSelect }: ProductModalProps) {
  const filteredProducts = useMemo(() => {
    if (!category) return [];
    return products.filter(product => product.category === category);
  }, [category]);

  const categoryLabel = useMemo(() => {
    if (!category) return '';
    return categories.find(c => c.value === category)?.label || '';
  }, [category]);

  if (!category) return null;

  return (
    <Modal isOpen={isOpen} onClose={onClose}>
      <div className="p-6">
        <h2 className="text-2xl font-bold mb-6">Choose {categoryLabel}</h2>
        
        <div className="space-y-4">
          {filteredProducts.map(product => (
            <div
              key={product.id}
              className="flex items-start gap-4 p-4 rounded-lg border border-gray-200 hover:border-blue-500 cursor-pointer"
              onClick={() => onSelect(product)}
            >
              <img
                src={product.image}
                alt={product.name}
                className="w-24 h-24 object-cover rounded-lg"
              />
              <div className="flex-1">
                <h3 className="font-semibold text-lg">{product.name}</h3>
                <p className="text-gray-600">{product.brand}</p>
                <p className="text-sm text-gray-600 mt-1">{product.description}</p>
                <div className="mt-2 grid grid-cols-2 gap-2">
                  {Object.entries(product.specs).slice(0, 4).map(([key, value]) => (
                    <div key={key} className="text-sm">
                      <span className="text-gray-600">{key}:</span>{' '}
                      <span className="font-medium">{value}</span>
                    </div>
                  ))}
                </div>
              </div>
              <div className="text-xl font-bold">
                ${product.price.toLocaleString()}
              </div>
            </div>
          ))}
        </div>
      </div>
    </Modal>
  );
}