import React, { useState } from 'react';
import { Link } from 'react-router-dom';
import { Bell } from 'lucide-react';
import { Product } from '../../types';
import { FavoriteButton } from '../FavoriteButton';
import { useCompare } from '../../hooks/useCompare';
import { usePriceAlertStore } from '../../stores/priceAlertStore';
import { useAuth } from '../../hooks/useAuth';
import { Toast } from '../ui/Toast';
import { AuthModal } from '../auth/AuthModal';

interface ProductTableRowProps {
  product: Product;
  onSelect: (product: Product) => void;
}

export function ProductTableRow({ product, onSelect }: ProductTableRowProps) {
  const [showToast, setShowToast] = React.useState(false);
  const [toastMessage, setToastMessage] = React.useState('');
  const [showAuthModal, setShowAuthModal] = useState(false);
  const { toggleCompare, isInComparison } = useCompare();
  const { isAuthenticated, user } = useAuth();
  const { alerts, addAlert, removeAlert } = usePriceAlertStore();
  
  const hasAlert = user && alerts.some(
    alert => alert.productId === product.id && alert.userId === user.id
  );

  const handleCompare = (e: React.MouseEvent) => {
    e.preventDefault();
    e.stopPropagation();
    toggleCompare(product);
  };

  const handlePriceAlert = (e: React.MouseEvent) => {
    e.preventDefault();
    e.stopPropagation();
    
    if (!isAuthenticated) {
      setShowAuthModal(true);
      return;
    }

    if (!user) return;

    if (hasAlert) {
      const alert = alerts.find(
        a => a.productId === product.id && a.userId === user.id
      );
      if (alert) {
        removeAlert(alert.id);
        setToastMessage('Price alert removed');
        setShowToast(true);
      }
    } else {
      addAlert({
        userId: user.id,
        productId: product.id,
        targetPrice: product.price,
        type: 'decrease'
      });
      setToastMessage('Price alert set');
      setShowToast(true);
    }
  };

  const mainSpecs = Object.entries(product.specs).slice(0, 2).map(([key, value]) => (
    `${key}: ${value}`
  )).join(' • ');

  return (
    <>
      <div className="px-6 py-4 grid grid-cols-12 gap-4 items-center hover:bg-gray-50">
        <div className="col-span-4">
          <div className="flex items-center gap-4">
            <img 
              src={product.image} 
              alt={product.name}
              className="w-12 h-12 object-cover rounded-lg"
            />
            <div>
              <div className="font-medium text-gray-900">{product.name}</div>
              <div className="flex items-center gap-2 mt-1">
                <FavoriteButton product={product} size="sm" />
                <input
                  type="checkbox"
                  className="custom-checkbox"
                  checked={isInComparison(product.id)}
                  onChange={handleCompare}
                  aria-label="Add to compare"
                />
                <button
                  onClick={handlePriceAlert}
                  className={`p-1.5 rounded-full transition-colors ${
                    hasAlert 
                      ? 'text-blue-600 bg-blue-50 hover:bg-blue-100' 
                      : 'text-gray-400 hover:bg-gray-50 hover:text-gray-500'
                  }`}
                  title={isAuthenticated ? (hasAlert ? 'Remove price alert' : 'Set price alert') : 'Sign in to set price alert'}
                >
                  <Bell className="h-4 w-4" />
                </button>
              </div>
            </div>
          </div>
        </div>
        
        <div className="col-span-2 text-gray-600">
          {product.brand}
        </div>

        <div className="col-span-3">
          <span className="text-sm text-gray-600 line-clamp-2">{mainSpecs}</span>
        </div>

        <div className="col-span-2">
          <span className="font-medium text-gray-900">
            ${product.price.toLocaleString()}
          </span>
        </div>

        <div className="col-span-1 flex justify-end space-x-2">
          <button
            onClick={() => onSelect(product)}
            className="text-sm text-blue-600 hover:text-blue-700 font-medium"
          >
            Add
          </button>
          <Link
            to={`/product/${product.id}`}
            className="text-sm text-gray-600 hover:text-gray-700"
          >
            Details
          </Link>
        </div>
      </div>

      <AuthModal 
        isOpen={showAuthModal} 
        onClose={() => setShowAuthModal(false)} 
      />

      {showToast && (
        <Toast
          message={toastMessage}
          type={hasAlert ? 'success' : 'info'}
          onClose={() => setShowToast(false)}
        />
      )}
    </>
  );
}