import React from 'react';
import { Product } from '../../types';
import { FavoriteButton } from '../FavoriteButton';
import { CompareButton } from './CompareButton';

interface CompareTableProps {
  products: Product[];
}

export function CompareTable({ products }: CompareTableProps) {
  if (products.length === 0) return null;

  // Get all unique spec keys from all products
  const specKeys = Array.from(
    new Set(products.flatMap(p => Object.keys(p.specs)))
  ).sort();

  // Find differences in specs
  const specDifferences = specKeys.reduce((acc, key) => {
    const values = products.map(p => p.specs[key]);
    acc[key] = new Set(values).size > 1;
    return acc;
  }, {} as Record<string, boolean>);

  return (
    <div className="overflow-x-auto">
      <table className="w-full">
        <thead>
          <tr className="border-b">
            <th className="text-left py-2 w-32">Product</th>
            {products.map(product => (
              <th key={product.id} className="px-6 py-2">
                <div className="flex items-start justify-between">
                  <div>
                    <div className="font-semibold text-left">{product.name}</div>
                    <div className="text-sm text-gray-600 font-normal">{product.brand}</div>
                  </div>
                  <div className="flex items-center gap-1">
                    <FavoriteButton product={product} size="sm" />
                    <CompareButton product={product} size="sm" />
                  </div>
                </div>
                <div className="text-lg font-bold text-left mt-1">
                  ${product.price.toLocaleString()}
                </div>
              </th>
            ))}
          </tr>
        </thead>
        <tbody>
          {specKeys.map(key => (
            <tr key={key} className={`border-b ${specDifferences[key] ? 'bg-blue-50' : ''}`}>
              <td className="py-2 text-sm font-medium text-gray-600">{key}</td>
              {products.map(product => (
                <td 
                  key={product.id} 
                  className={`px-6 py-2 ${
                    specDifferences[key] ? 'font-medium text-blue-900' : ''
                  }`}
                >
                  {product.specs[key] || '-'}
                </td>
              ))}
            </tr>
          ))}
        </tbody>
      </table>
    </div>
  );
}