import React, { useState } from 'react';
import { Link, useNavigate } from 'react-router-dom';
import { Plus, MessageSquare } from 'lucide-react';
import { useForumStore } from '../../stores/forumStore';
import { useAuth } from '../../hooks/useAuth';
import { ThreadListItem } from './ThreadListItem';
import { SearchBar } from '../SearchBar';

const categories = [
  {
    title: "Equipment & Setup",
    description: "Launch monitors, projectors, screens, and hardware discussions",
    tags: ['launch-monitors', 'projectors', 'screens', 'hardware', 'equipment']
  },
  {
    title: "Software & Games",
    description: "Golf simulation software, course libraries, and game features",
    tags: ['software', 'gaming', 'courses']
  },
  {
    title: "Build & Installation",
    description: "Build guides, installation tips, and room setup advice",
    tags: ['diy', 'build-guide', 'setup', 'installation']
  },
  {
    title: "Troubleshooting & Support",
    description: "Technical support, calibration, and problem solving",
    tags: ['technical', 'support', 'calibration']
  }
];

export function ThreadList() {
  const { threads } = useForumStore();
  const { isAuthenticated } = useAuth();
  const navigate = useNavigate();
  const [searchQuery, setSearchQuery] = useState('');

  const filteredThreads = React.useMemo(() => {
    if (!searchQuery) return threads;
    const query = searchQuery.toLowerCase();
    return threads.filter(thread => 
      thread.title.toLowerCase().includes(query) ||
      thread.content.toLowerCase().includes(query) ||
      thread.tags.some(tag => tag.toLowerCase().includes(query))
    );
  }, [threads, searchQuery]);

  const categorizedThreads = React.useMemo(() => {
    return categories.map(category => ({
      ...category,
      threads: filteredThreads.filter(thread =>
        thread.tags.some(tag => category.tags.includes(tag))
      )
    }));
  }, [filteredThreads]);

  const uncategorizedThreads = React.useMemo(() => {
    const categorizedTags = categories.flatMap(c => c.tags);
    return filteredThreads.filter(thread =>
      !thread.tags.some(tag => categorizedTags.includes(tag))
    );
  }, [filteredThreads]);

  return (
    <div>
      <div className="flex justify-between items-center mb-6">
        <div>
          <h1 className="text-2xl font-bold text-gray-900">Forum Discussions</h1>
          <p className="text-gray-600 mt-1">
            Join the conversation about golf simulators
          </p>
        </div>
        {isAuthenticated && (
          <button
            onClick={() => navigate('/forum/new')}
            className="inline-flex items-center gap-2 px-4 py-2 bg-blue-600 text-white rounded-md hover:bg-blue-700"
          >
            <Plus className="h-4 w-4" />
            New Thread
          </button>
        )}
      </div>

      <div className="mb-6">
        <SearchBar
          value={searchQuery}
          onChange={setSearchQuery}
          placeholder="Search discussions..."
        />
      </div>

      {searchQuery ? (
        <div className="bg-white rounded-lg shadow-md divide-y">
          {filteredThreads.map(thread => (
            <ThreadListItem key={thread.id} thread={thread} />
          ))}
        </div>
      ) : (
        <div className="space-y-8">
          {categorizedThreads.map(category => (
            <div key={category.title}>
              <div className="mb-4">
                <h2 className="text-lg font-semibold text-gray-900">{category.title}</h2>
                <p className="text-sm text-gray-600">{category.description}</p>
              </div>
              {category.threads.length > 0 ? (
                <div className="bg-white rounded-lg shadow-md divide-y">
                  {category.threads.map(thread => (
                    <ThreadListItem key={thread.id} thread={thread} />
                  ))}
                </div>
              ) : (
                <div className="bg-white rounded-lg shadow-md p-6 text-center text-gray-500">
                  No discussions in this category yet
                </div>
              )}
            </div>
          ))}

          {uncategorizedThreads.length > 0 && (
            <div>
              <div className="mb-4">
                <h2 className="text-lg font-semibold text-gray-900">General Discussion</h2>
                <p className="text-sm text-gray-600">Other golf simulator related topics</p>
              </div>
              <div className="bg-white rounded-lg shadow-md divide-y">
                {uncategorizedThreads.map(thread => (
                  <ThreadListItem key={thread.id} thread={thread} />
                ))}
              </div>
            </div>
          )}
        </div>
      )}

      {filteredThreads.length === 0 && (
        <div className="text-center py-12 bg-white rounded-lg shadow-md">
          <MessageSquare className="h-12 w-12 text-gray-400 mx-auto mb-4" />
          <h3 className="text-lg font-medium text-gray-900 mb-2">
            No discussions found
          </h3>
          <p className="text-gray-600 mb-6">
            {searchQuery ? 'Try different search terms' : 'Be the first to start a discussion'}
          </p>
          {isAuthenticated ? (
            <Link
              to="/forum/new"
              className="inline-flex items-center px-4 py-2 border border-transparent text-sm font-medium rounded-md shadow-sm text-white bg-blue-600 hover:bg-blue-700"
            >
              Start a Thread
            </Link>
          ) : (
            <Link
              to="/login"
              className="inline-flex items-center px-4 py-2 border border-transparent text-sm font-medium rounded-md shadow-sm text-white bg-blue-600 hover:bg-blue-700"
            >
              Sign in to Start a Thread
            </Link>
          )}
        </div>
      )}
    </div>
  );
}