import React, { useEffect, useState } from 'react';
import { useParams, Link, useNavigate } from 'react-router-dom';
import { ChevronLeft, MoreVertical, Edit2, Trash2, Image as ImageIcon } from 'lucide-react';
import { useForumStore } from '../../stores/forumStore';
import { ReplyList } from './ReplyList';
import { ReplyForm } from './ReplyForm';
import { useAuth } from '../../hooks/useAuth';
import { formatDate } from '../../utils/date';
import { Modal } from '../Modal';
import { Toast } from '../ui/Toast';

export function ThreadView() {
  const { threadId } = useParams<{ threadId: string }>();
  const navigate = useNavigate();
  const { threads, replies, incrementViews, updateThread, deleteThread } = useForumStore();
  const { user } = useAuth();
  const [isMenuOpen, setIsMenuOpen] = useState(false);
  const [isEditMode, setIsEditMode] = useState(false);
  const [editedTitle, setEditedTitle] = useState('');
  const [editedContent, setEditedContent] = useState('');
  const [editedImage, setEditedImage] = useState<string | null>(null);
  const [showDeleteModal, setShowDeleteModal] = useState(false);
  const [showToast, setShowToast] = useState(false);
  
  const thread = threads.find(t => t.id === threadId);
  const threadReplies = replies[threadId!] || [];
  const isAuthor = user?.id === thread?.author.id;

  useEffect(() => {
    if (threadId) {
      incrementViews(threadId);
    }
  }, [threadId, incrementViews]);

  useEffect(() => {
    if (thread && isEditMode) {
      setEditedTitle(thread.title);
      setEditedContent(thread.content);
      setEditedImage(thread.image || null);
    }
  }, [thread, isEditMode]);

  const handleImageUpload = (e: React.ChangeEvent<HTMLInputElement>) => {
    const file = e.target.files?.[0];
    if (file) {
      const reader = new FileReader();
      reader.onloadend = () => {
        setEditedImage(reader.result as string);
      };
      reader.readAsDataURL(file);
    }
  };

  if (!thread) {
    return <div>Thread not found</div>;
  }

  const handleEdit = () => {
    setIsMenuOpen(false);
    setIsEditMode(true);
  };

  const handleSave = () => {
    if (threadId) {
      updateThread(threadId, {
        title: editedTitle,
        content: editedContent,
        image: editedImage
      });
      setIsEditMode(false);
      setShowToast(true);
    }
  };

  const handleDelete = () => {
    if (threadId) {
      deleteThread(threadId);
      navigate('/forum');
    }
  };

  return (
    <div>
      <div className="mb-6">
        <Link
          to="/forum"
          className="inline-flex items-center text-gray-600 hover:text-gray-900"
        >
          <ChevronLeft className="h-5 w-5" />
          <span>Back to Forum</span>
        </Link>
      </div>

      <div className="bg-white rounded-lg shadow-md">
        <div className="p-6 border-b">
          <div className="flex justify-between items-start">
            {isEditMode ? (
              <div className="w-full space-y-4">
                <input
                  type="text"
                  value={editedTitle}
                  onChange={(e) => setEditedTitle(e.target.value)}
                  className="w-full px-3 py-2 border rounded-md"
                />
                <textarea
                  value={editedContent}
                  onChange={(e) => setEditedContent(e.target.value)}
                  className="w-full px-3 py-2 border rounded-md h-32"
                />
                <div>
                  <label className="flex items-center gap-2 px-4 py-2 bg-white border border-gray-300 rounded-md hover:bg-gray-50 cursor-pointer inline-block">
                    <ImageIcon className="h-5 w-5 text-gray-500" />
                    <span className="text-sm text-gray-700">
                      {editedImage ? 'Change Image' : 'Add Image'}
                    </span>
                    <input
                      type="file"
                      accept="image/*"
                      onChange={handleImageUpload}
                      className="hidden"
                    />
                  </label>
                  {editedImage && (
                    <div className="mt-2 relative inline-block">
                      <img
                        src={editedImage}
                        alt="Preview"
                        className="h-20 w-20 object-cover rounded-md"
                      />
                      <button
                        type="button"
                        onClick={() => setEditedImage(null)}
                        className="absolute -top-2 -right-2 p-1 bg-red-100 rounded-full text-red-600 hover:bg-red-200"
                      >
                        ×
                      </button>
                    </div>
                  )}
                </div>
                <div className="flex justify-end gap-2">
                  <button
                    onClick={() => setIsEditMode(false)}
                    className="px-4 py-2 text-gray-600 hover:text-gray-900"
                  >
                    Cancel
                  </button>
                  <button
                    onClick={handleSave}
                    className="px-4 py-2 bg-blue-600 text-white rounded-md hover:bg-blue-700"
                  >
                    Save Changes
                  </button>
                </div>
              </div>
            ) : (
              <>
                <div>
                  <h1 className="text-2xl font-bold text-gray-900 mb-2">
                    {thread.title}
                  </h1>
                  <div className="flex items-center gap-4 text-sm text-gray-500">
                    <span>Posted by {thread.author.username}</span>
                    <span>•</span>
                    <span>{formatDate(thread.createdAt)}</span>
                  </div>
                </div>
                {isAuthor && (
                  <div className="relative">
                    <button
                      onClick={() => setIsMenuOpen(!isMenuOpen)}
                      className="p-2 hover:bg-gray-100 rounded-full"
                    >
                      <MoreVertical className="h-5 w-5" />
                    </button>
                    {isMenuOpen && (
                      <>
                        <div
                          className="fixed inset-0 z-10"
                          onClick={() => setIsMenuOpen(false)}
                        />
                        <div className="absolute right-0 mt-2 w-48 bg-white rounded-md shadow-lg z-20 py-1">
                          <button
                            onClick={handleEdit}
                            className="flex items-center gap-2 w-full px-4 py-2 text-left text-gray-700 hover:bg-gray-100"
                          >
                            <Edit2 className="h-4 w-4" />
                            Edit Thread
                          </button>
                          <button
                            onClick={() => setShowDeleteModal(true)}
                            className="flex items-center gap-2 w-full px-4 py-2 text-left text-red-600 hover:bg-gray-100"
                          >
                            <Trash2 className="h-4 w-4" />
                            Delete Thread
                          </button>
                        </div>
                      </>
                    )}
                  </div>
                )}
              </>
            )}
          </div>
          {!isEditMode && (
            <>
              <div className="mt-6 prose max-w-none">
                {thread.content}
              </div>
              {thread.image && (
                <div className="mt-4">
                  <img
                    src={thread.image}
                    alt="Thread image"
                    className="max-w-full max-h-96 object-contain rounded-lg"
                  />
                </div>
              )}
            </>
          )}
        </div>

        <ReplyList replies={threadReplies} />

        {user ? (
          <div className="p-6 bg-gray-50">
            <ReplyForm threadId={thread.id} />
          </div>
        ) : (
          <div className="p-6 bg-gray-50 text-center">
            <Link
              to="/login"
              className="text-blue-600 hover:text-blue-700"
            >
              Sign in to reply
            </Link>
          </div>
        )}
      </div>

      <Modal
        isOpen={showDeleteModal}
        onClose={() => setShowDeleteModal(false)}
      >
        <div className="p-6">
          <h2 className="text-xl font-semibold mb-4">Delete Thread</h2>
          <p className="text-gray-600 mb-6">
            Are you sure you want to delete this thread? This action cannot be undone.
          </p>
          <div className="flex justify-end gap-3">
            <button
              onClick={() => setShowDeleteModal(false)}
              className="px-4 py-2 text-gray-600 hover:text-gray-900"
            >
              Cancel
            </button>
            <button
              onClick={handleDelete}
              className="px-4 py-2 bg-red-600 text-white rounded-md hover:bg-red-700"
            >
              Delete Thread
            </button>
          </div>
        </div>
      </Modal>

      {showToast && (
        <Toast
          message="Thread updated successfully"
          type="success"
          onClose={() => setShowToast(false)}
        />
      )}
    </div>
  );
}