import { useState, useEffect } from 'react';
import { ProductCategory } from '../types';
import { products } from '../data/products';

interface PricePoint {
  date: string;
  price: number;
}

interface ProductTrend {
  productId: string;
  name: string;
  data: PricePoint[];
}

export function usePriceTrends(category: ProductCategory, timeRange: '1M' | '3M' | '6M' | '1Y') {
  const [data, setData] = useState<any>(null);
  const [isLoading, setIsLoading] = useState(true);

  useEffect(() => {
    // Get products for the selected category
    const categoryProducts = products.filter(p => p.category === category);

    // Generate mock historical data
    const getDays = () => {
      switch (timeRange) {
        case '1M': return 30;
        case '3M': return 90;
        case '6M': return 180;
        case '1Y': return 365;
      }
    };

    const generateTrend = (basePrice: number): PricePoint[] => {
      const days = getDays();
      const trend: PricePoint[] = [];
      let currentPrice = basePrice;

      for (let i = days; i >= 0; i--) {
        const date = new Date();
        date.setDate(date.getDate() - i);
        
        // Add some random price fluctuation
        const change = (Math.random() - 0.5) * (basePrice * 0.02);
        currentPrice += change;
        
        trend.push({
          date: date.toISOString().split('T')[0],
          price: Math.round(currentPrice)
        });
      }

      return trend;
    };

    // Generate trends for each product
    const trends: ProductTrend[] = categoryProducts.map(product => ({
      productId: product.id,
      name: product.name,
      data: generateTrend(product.price)
    }));

    // Format data for Chart.js
    const chartData = {
      labels: trends[0].data.map(d => d.date),
      datasets: trends.map((trend, index) => ({
        label: trend.name,
        data: trend.data.map(d => d.price),
        borderColor: [
          '#2563eb',
          '#7c3aed',
          '#db2777',
          '#ea580c',
          '#65a30d'
        ][index % 5],
        backgroundColor: [
          '#2563eb33',
          '#7c3aed33',
          '#db277733',
          '#ea580c33',
          '#65a30d33'
        ][index % 5],
        tension: 0.3,
        fill: false
      }))
    };

    setData(chartData);
    setIsLoading(false);
  }, [category, timeRange]);

  return { data, isLoading };
}