import { useState, useEffect } from 'react';
import { useAuth } from './useAuth';
import { Product } from '../types';

export interface SavedBuild {
  id: string;
  name: string;
  products: Product[];
  createdAt: string;
  updatedAt: string;
}

export function useSavedBuilds() {
  const { user } = useAuth();
  const [savedBuilds, setSavedBuilds] = useState<SavedBuild[]>([]);
  const [isLoading, setIsLoading] = useState(true);

  useEffect(() => {
    if (!user) {
      setSavedBuilds([]);
      setIsLoading(false);
      return;
    }

    const loadSavedBuilds = () => {
      try {
        const stored = localStorage.getItem(`builds_${user.id}`);
        if (stored) {
          setSavedBuilds(JSON.parse(stored));
        }
      } catch (error) {
        console.error('Failed to load saved builds:', error);
      } finally {
        setIsLoading(false);
      }
    };

    loadSavedBuilds();
  }, [user]);

  const saveBuild = (name: string, products: Product[]) => {
    if (!user) return;

    const newBuild: SavedBuild = {
      id: crypto.randomUUID(),
      name,
      products,
      createdAt: new Date().toISOString(),
      updatedAt: new Date().toISOString()
    };

    const updatedBuilds = [...savedBuilds, newBuild];
    localStorage.setItem(`builds_${user.id}`, JSON.stringify(updatedBuilds));
    setSavedBuilds(updatedBuilds);
  };

  const updateBuild = (buildId: string, updates: Partial<SavedBuild>) => {
    if (!user) return;

    const updatedBuilds = savedBuilds.map(build => {
      if (build.id === buildId) {
        return {
          ...build,
          ...updates,
          updatedAt: new Date().toISOString()
        };
      }
      return build;
    });

    localStorage.setItem(`builds_${user.id}`, JSON.stringify(updatedBuilds));
    setSavedBuilds(updatedBuilds);
  };

  const deleteBuild = (buildId: string) => {
    if (!user) return;

    const updatedBuilds = savedBuilds.filter(build => build.id !== buildId);
    localStorage.setItem(`builds_${user.id}`, JSON.stringify(updatedBuilds));
    setSavedBuilds(updatedBuilds);
  };

  return {
    savedBuilds,
    isLoading,
    saveBuild,
    updateBuild,
    deleteBuild
  };
}