import React, { useState } from 'react';
import { useParams, useNavigate } from 'react-router-dom';
import { ChevronLeft } from 'lucide-react';
import { Product } from '../types';
import { products } from '../data/products';
import { categories } from '../data/categories';
import { ProductTable } from '../components/ProductTable/ProductTable';
import { FilterSection } from '../components/Filters/FilterSection';
import { useFilters } from '../hooks/useFilters';
import { CompareInstructions } from '../components/compare/CompareInstructions';
import { useCompareMode } from '../hooks/useCompareMode';
import { SearchBar } from '../components/SearchBar';
import { useBuildHistory } from '../hooks/useBuildHistory';

interface CategoryPageProps {
  selectedProducts: Product[];
  setSelectedProducts: (products: Product[]) => void;
}

export function CategoryPage({ selectedProducts, setSelectedProducts }: CategoryPageProps) {
  const { categoryId } = useParams<{ categoryId: string }>();
  const navigate = useNavigate();
  const { isActive } = useCompareMode();
  const { addToHistory } = useBuildHistory();
  const [searchQuery, setSearchQuery] = useState('');

  const categoryProducts = React.useMemo(() => {
    return products.filter(product => product.category === categoryId);
  }, [categoryId]);

  const {
    minPrice,
    maxPrice,
    setMinPrice,
    setMaxPrice,
    brands,
    selectedBrands,
    setSelectedBrands,
    filteredProducts
  } = useFilters(categoryProducts);

  const searchedProducts = React.useMemo(() => {
    if (!searchQuery) return filteredProducts;
    const query = searchQuery.toLowerCase();
    return filteredProducts.filter(product => 
      product.name.toLowerCase().includes(query) ||
      product.brand.toLowerCase().includes(query) ||
      product.description.toLowerCase().includes(query)
    );
  }, [filteredProducts, searchQuery]);

  const categoryLabel = React.useMemo(() => {
    return categories.find(c => c.value === categoryId)?.label || '';
  }, [categoryId]);

  const handleSelectProduct = (product: Product) => {
    if (!isActive) {
      setSelectedProducts(prev => {
        const filtered = prev.filter(p => p.category !== product.category);
        return [...filtered, product];
      });
      addToHistory(product, 'added');
      navigate('/');
    }
  };

  return (
    <main className="max-w-7xl mx-auto px-4 py-8">
      <div className="flex items-center gap-4 mb-8">
        <button
          onClick={() => navigate('/')}
          className="flex items-center gap-2 text-gray-600 hover:text-gray-900"
        >
          <ChevronLeft className="h-5 w-5" />
          Back to Builder
        </button>
        <h1 className="text-2xl font-bold text-gray-900">Choose {categoryLabel}</h1>
      </div>

      {isActive && <CompareInstructions />}

      <div className="grid grid-cols-12 gap-8">
        <div className="col-span-3">
          <FilterSection
            brands={brands}
            selectedBrands={selectedBrands}
            onBrandChange={setSelectedBrands}
            minPrice={minPrice}
            maxPrice={maxPrice}
            onPriceChange={(min, max) => {
              setMinPrice(min);
              setMaxPrice(max);
            }}
          />
        </div>

        <div className="col-span-9">
          <div className="mb-6">
            <SearchBar 
              value={searchQuery}
              onChange={setSearchQuery}
              placeholder={`Search ${categoryLabel.toLowerCase()}...`}
            />
          </div>
          <ProductTable
            products={searchedProducts}
            onSelect={handleSelectProduct}
          />
        </div>
      </div>
    </main>
  );
}