import React from 'react';
import { BuildGrid } from '../components/community/BuildGrid';
import { BuildFilters } from '../components/community/BuildFilters';
import { useCommunityStore } from '../stores/communityStore';

export function CommunityBuildsPage() {
  const { builds } = useCommunityStore();
  const [filters, setFilters] = React.useState({
    sort: 'recent',
    minPrice: 0,
    maxPrice: Infinity,
    tags: []
  });

  const filteredBuilds = React.useMemo(() => {
    let filtered = [...builds];

    // Apply filters
    if (filters.tags.length > 0) {
      filtered = filtered.filter(build =>
        build.tags.some(tag => filters.tags.includes(tag))
      );
    }

    const totalPrice = (build: typeof builds[0]) =>
      build.products.reduce((sum, p) => sum + p.price, 0);

    filtered = filtered.filter(build => {
      const price = totalPrice(build);
      return price >= filters.minPrice && price <= filters.maxPrice;
    });

    // Apply sorting
    switch (filters.sort) {
      case 'popular':
        filtered.sort((a, b) => b.likes - a.likes);
        break;
      case 'budget':
        filtered.sort((a, b) => totalPrice(a) - totalPrice(b));
        break;
      case 'premium':
        filtered.sort((a, b) => totalPrice(b) - totalPrice(a));
        break;
      default: // recent
        filtered.sort((a, b) => 
          new Date(b.createdAt).getTime() - new Date(a.createdAt).getTime()
        );
    }

    return filtered;
  }, [builds, filters]);

  return (
    <main className="max-w-7xl mx-auto px-4 py-8">
      <div className="mb-8">
        <h1 className="text-2xl font-bold text-gray-900">Community Builds</h1>
        <p className="text-gray-600 mt-1">
          Discover and get inspired by simulator builds from the community
        </p>
      </div>

      <div className="grid grid-cols-12 gap-8">
        <div className="col-span-3">
          <BuildFilters filters={filters} onChange={setFilters} />
        </div>
        <div className="col-span-9">
          <BuildGrid builds={filteredBuilds} isLoading={false} />
        </div>
      </div>
    </main>
  );
}